/*************************************************************************
DESCRIPTION :
The TTCsynchronizer crosses the clock domanins from TTC_CK40Des1 to clk.
The input pulse must be longer than 12.5 ns for the circuit to work.
This covers the ample jitter of the TTC signals (25ns +/- jitter).
The resulting output signal is a 1-clk-tick pulse.
***************************************************************************/

`timescale 1ns / 1ns
module TTCsynchronizer 
 (
 input   clk, clk2x,  t_Command,  
 output  reg  Command           );

 reg Command_clk2x;
 reg [5:1] CommandD = 0; // this should avoid glitches at power-up.
 
 always @ (posedge clk2x)    // digital edge-detection of t_Command
   begin 
     CommandD[1]   <= t_Command;
     CommandD[2]   <= CommandD[1];
     CommandD[3]   <= CommandD[2];
     Command_clk2x <= CommandD[1] | CommandD[2] | CommandD[3];// ultra-conservative
   end

 always @ (posedge clk )   begin   
    // detect transition 0->1 and make a 25-ns pulse
    CommandD[4] <= Command_clk2x;    
    CommandD[5] <= CommandD[4];  
    Command    <= CommandD[4]  & ~CommandD[5];   
  end  
    
endmodule  